@@ -184,6 +184,10 @@ def _dynamodb_to_python(schema_type, value):
     # This means a missing attribute for a _JSON_TYPES object is valid,
     # and results in an empty sequence. Is that a bad thing?
     if value is None:
+        if schema_type == datetime.datetime:
+            # Default value for unsupplied datetimes:
+            # the beginning of the UNIX epoch.
+            return datetime.datetime.now(tz=utc_tz)
         # Empty sets/strings are represented as missing attributes
         return schema_type()
 
